@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2010 by Barry A. Warsaw
+# Copyright (C) 2004-2011 by Barry A. Warsaw
 #
 # This file is part of flufl.enum
 #
@@ -20,11 +20,13 @@ from __future__ import absolute_import, unicode_literals
 
 __metaclass__ = type
 __all__ = [
-    'Enum',
+    b'Enum',
+    b'__version__',
+    b'make_enum',
     ]
 
 
-__version__ = '3.0.1'
+__version__ = '3.1'
 
 
-from ._enum import Enum
+from ._enum import Enum, make_enum
