@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2010 by Barry A. Warsaw
+# Copyright (C) 2004-2011 by Barry A. Warsaw
 #
 # This file is part of flufl.enum
 #
@@ -20,7 +20,8 @@ from __future__ import absolute_import, unicode_literals
 
 __metaclass__ = type
 __all__ = [
-    'Enum',
+    b'Enum',
+    b'make_enum',
     ]
 
 
@@ -114,6 +115,9 @@ class EnumValue:
     def __int__(self):
         return self._value
 
+    def __reduce__(self):
+        return getattr, (self._class, self._enumname)
+
     @property
     def enumclass(self):
         """Return the class associated with the enum value."""
@@ -147,3 +151,26 @@ class Enum:
 
     # pylint: disable-msg=W0232
     __metaclass__ = EnumMetaclass
+
+
+
+def make_enum(name, value_string):
+    """Return an Enum class from a name and a value string.
+
+    This is a convenience function for defining a new enumeration when you
+    don't care about the values of the items.  The values are automatically
+    created by splitting the value string on spaces.
+
+    :param name: The resulting enum's class name.
+    :type name: byte string (or ASCII-only unicode string)
+    :param value_string: A string of enumeration item names, separated by
+        spaces, e.g. 'one two three'.
+    :type value_string: byte string (or ASCII-only unicode string)
+    :return: The new enumeration class.
+    :rtype: instance of `EnumMetaClass`
+    """
+    value_names = value_string.split()
+    return EnumMetaclass(
+        str(name), (Enum,),
+        dict((str(value), i) for i, value in enumerate(value_names, 1))
+        )
